@@ -1,11 +1,10 @@
 """
 Provides an emulator/replacement for Python's standard import system.
 
-@@TR: Be warned that Import Hooks are in the deepest, darkest corner of Python's
-jungle.  If you need to start hacking with this, be prepared to get lost for a
-while. Also note, this module predates the newstyle import hooks in Python 2.3
-http://www.python.org/peps/pep-0302.html.
-
+@@TR: Be warned that Import Hooks are in the deepest, darkest corner of
+Python's jungle.  If you need to start hacking with this, be prepared to get
+lost for a while. Also note, this module predates the newstyle import hooks in
+Python 2.3 http://www.python.org/peps/pep-0302.html.
 
 This is a hacked/documented version of Gordon McMillan's iu.py. I have:
 
@@ -16,12 +15,12 @@ This is a hacked/documented version of Gordon McMillan's iu.py. I have:
   - standardized the variable naming scheme
 
   - reorganized the code layout to enhance readability
-
 """
 
-import sys
 import imp
 import marshal
+import py_compile
+import sys
 from Cheetah.compat import string_type
 
 _installed = False
@@ -31,10 +30,13 @@ _installed = False
 _os_stat = _os_path_join = _os_getcwd = _os_path_dirname = None
 
 ##################################################
-## FUNCTIONS
+# FUNCTIONS
+
 
 def _os_bootstrap():
-    """Set up 'os' module replacement functions for use during import bootstrap."""
+    """
+    Set up 'os' module replacement functions for use during import bootstrap
+    """
 
     names = sys.builtin_module_names
 
@@ -53,6 +55,7 @@ def _os_bootstrap():
         from os2 import stat, getcwd
     elif 'mac' in names:
         from mac import stat, getcwd
+
         def join(a, b):
             if a == '':
                 return b
@@ -75,7 +78,7 @@ def _os_bootstrap():
 
     if dirname is None:
         def dirname(a, sep=sep):
-            for i in range(len(a)-1, -1, -1):
+            for i in range(len(a) - 1, -1, -1):
                 c = a[i]
                 if c == '/' or c == sep:
                     return a[:i]
@@ -93,33 +96,38 @@ def _os_bootstrap():
     global _os_getcwd
     _os_getcwd = getcwd
 
+
 _os_bootstrap()
 
+
 def packageName(s):
-    for i in range(len(s)-1, -1, -1):
+    for i in range(len(s) - 1, -1, -1):
         if s[i] == '.':
             break
     else:
         return ''
     return s[:i]
 
+
 def nameSplit(s):
     rslt = []
     i = j = 0
     for j in range(len(s)):
         if s[j] == '.':
             rslt.append(s[i:j])
-            i = j+1
+            i = j + 1
     if i < len(s):
         rslt.append(s[i:])
     return rslt
 
+
 def getPathExt(fnm):
-    for i in range(len(fnm)-1, -1, -1):
+    for i in range(len(fnm) - 1, -1, -1):
         if fnm[i] == '.':
             return fnm[i:]
     return ''
 
+
 def pathIsDir(pathname):
     "Local replacement for os.path.isdir()."
     try:
@@ -128,6 +136,7 @@ def pathIsDir(pathname):
         return None
     return (s[0] & 0o170000) == 0o040000
 
+
 def getDescr(fnm):
     ext = getPathExt(fnm)
     for (suffix, mode, typ) in imp.get_suffixes():
@@ -135,7 +144,8 @@ def getDescr(fnm):
             return (suffix, mode, typ)
 
 ##################################################
-## CLASSES
+# CLASSES
+
 
 class Owner:
 
@@ -143,7 +153,8 @@ class Owner:
     an Owner for each thing on sys.path There are owners for directories and
     .pyz files.  There could be owners for zip files, or even URLs.  A
     shadowpath (a dictionary mapping the names in sys.path to their owners) is
-    used so that sys.path (or a package's __path__) is still a bunch of strings,
+    used so that sys.path (or a package's __path__) is still a bunch of
+    strings.
     """
 
     def __init__(self, path):
@@ -155,6 +166,7 @@ class Owner:
     def getmod(self, nm):
         return None
 
+
 class DirOwner(Owner):
 
     def __init__(self, path):
@@ -164,10 +176,10 @@ class DirOwner(Owner):
             raise ValueError("%s is not a directory" % path)
         Owner.__init__(self, path)
 
-    def getmod(self, nm,
-               getsuffixes=imp.get_suffixes, loadco=marshal.loads, newmod=imp.new_module):
+    def getmod(self, nm, getsuffixes=imp.get_suffixes,
+               loadco=marshal.loads, newmod=imp.new_module):
 
-        pth =  _os_path_join(self.path, nm)
+        pth = _os_path_join(self.path, nm)
 
         possibles = [(pth, 0, None)]
         if pathIsDir(pth):
@@ -175,17 +187,18 @@ class DirOwner(Owner):
         py = pyc = None
         for pth, ispkg, pkgpth in possibles:
             for ext, mode, typ in getsuffixes():
-                attempt = pth+ext
+                attempt = pth + ext
                 try:
                     st = _os_stat(attempt)
-                except:
+                except Exception:
                     pass
                 else:
                     if typ == imp.C_EXTENSION:
-                        fp = open(attempt, 'rb')
-                        mod = imp.load_module(nm, fp, attempt, (ext, mode, typ))
-                        mod.__file__ = attempt
-                        return mod
+                        with open(attempt, 'rb') as fp:
+                            mod = imp.load_module(
+                                nm, fp, attempt, (ext, mode, typ))
+                            mod.__file__ = attempt
+                            return mod
                     elif typ == imp.PY_SOURCE:
                         py = (attempt, st)
                     else:
@@ -197,23 +210,32 @@ class DirOwner(Owner):
         while True:
             if pyc is None or py and pyc[1][8] < py[1][8]:
                 try:
-                    co = compile(open(py[0], 'r').read()+'\n', py[0], 'exec')
+                    with open(py[0], 'r') as py_code_file:
+                        py_code = py_code_file.read()
+                    co = compile(py_code + '\n', py[0], 'exec')
+                    try:
+                        py_compile.compile(py[0])
+                    except IOError:
+                        pass
+                    __file__ = py[0]
                     break
                 except SyntaxError as e:
                     print("Invalid syntax in %s" % py[0])
                     print(e.args)
                     raise
             elif pyc:
-                stuff = open(pyc[0], 'rb').read()
+                with open(pyc[0], 'rb') as pyc_file:
+                    stuff = pyc_file.read()
                 try:
                     co = loadco(stuff[8:])
+                    __file__ = pyc[0]
                     break
                 except (ValueError, EOFError):
                     pyc = None
             else:
                 return None
         mod = newmod(nm)
-        mod.__file__ = co.co_filename
+        mod.__file__ = __file__
         if ispkg:
             mod.__path__ = [pkgpth]
             subimporter = PathImportDirector(mod.__path__)
@@ -230,6 +252,7 @@ class ImportDirector(Owner):
 
     pass
 
+
 class BuiltinImportDirector(ImportDirector):
     """Directs imports of builtin modules"""
     def __init__(self):
@@ -241,6 +264,7 @@ class BuiltinImportDirector(ImportDirector):
             return mod
         return None
 
+
 class FrozenImportDirector(ImportDirector):
     """Directs imports of frozen modules"""
 
@@ -252,7 +276,9 @@ class FrozenImportDirector(ImportDirector):
         if isFrozen(nm):
             mod = loadMod(nm, None, nm, ('', '', imp.PY_FROZEN))
             if hasattr(mod, '__path__'):
-                mod.__importsub__ = lambda name, pname=nm, owner=self: owner.getmod(pname+'.'+name)
+                mod.__importsub__ = \
+                    lambda name, pname=nm, owner=self: \
+                    owner.getmod(pname + '.' + name)
             return mod
         return None
 
@@ -265,7 +291,7 @@ class RegistryImportDirector(ImportDirector):
         self.map = {}
         try:
             import win32api
-            ## import win32con
+            # import win32con
         except ImportError:
             pass
         else:
@@ -275,14 +301,17 @@ class RegistryImportDirector(ImportDirector):
             subkey = r"Software\Python\PythonCore\%s\Modules" % sys.winver
             for root in (HKEY_CURRENT_USER, HKEY_LOCAL_MACHINE):
                 try:
-                    hkey = win32api.RegOpenKeyEx(root, subkey, 0, KEY_ALL_ACCESS)
-                except:
+                    hkey = win32api.RegOpenKeyEx(root, subkey,
+                                                 0, KEY_ALL_ACCESS)
+                except Exception:
                     pass
                 else:
-                    numsubkeys, numvalues, lastmodified = win32api.RegQueryInfoKey(hkey)
+                    numsubkeys, numvalues, lastmodified = \
+                        win32api.RegQueryInfoKey(hkey)
                     for i in range(numsubkeys):
                         subkeyname = win32api.RegEnumKey(hkey, i)
-                        hskey = win32api.RegOpenKeyEx(hkey, subkeyname, 0, KEY_ALL_ACCESS)
+                        hskey = win32api.RegOpenKeyEx(hkey, subkeyname,
+                                                      0, KEY_ALL_ACCESS)
                         val = win32api.RegQueryValueEx(hskey, '')
                         desc = getDescr(val[0])
                         self.map[subkeyname] = (val[0], desc)
@@ -294,12 +323,13 @@ class RegistryImportDirector(ImportDirector):
         stuff = self.map.get(nm)
         if stuff:
             fnm, desc = stuff
-            fp = open(fnm, 'rb')
-            mod = imp.load_module(nm, fp, fnm, desc)
-            mod.__file__ = fnm
-            return mod
+            with open(fnm, 'rb') as fp:
+                mod = imp.load_module(nm, fp, fnm, desc)
+                mod.__file__ = fnm
+                return mod
         return None
 
+
 class PathImportDirector(ImportDirector):
     """Directs imports of modules stored on the filesystem."""
 
@@ -308,7 +338,7 @@ class PathImportDirector(ImportDirector):
             self.path = sys.path
         else:
             self.path = pathlist
-        if ownertypes == None:
+        if ownertypes is None:
             self._ownertypes = _globalOwnerTypes
         else:
             self._ownertypes = ownertypes
@@ -344,19 +374,21 @@ class PathImportDirector(ImportDirector):
                 # this may cause an import, which may cause recursion
                 # hence the protection
                 owner = klass(path)
-            except:
+            except Exception:
                 pass
             else:
                 break
         del self._building[path]
         return owner
 
-#=================ImportManager============================#
+# =================ImportManager============================#
 # The one-and-only ImportManager
 # ie, the builtin import
 
+
 UNTRIED = -1
 
+
 class ImportManager:
     # really the equivalent of builtin import
     def __init__(self):
@@ -386,11 +418,13 @@ class ImportManager:
         builtin.__import__ = self.importHook
         builtin.reload = self.reloadHook
 
-    def importHook(self, name, globals=None, locals=None, fromlist=None, level=-1):
+    def importHook(self, name, globals=None, locals=None,
+                   fromlist=None, level=-1):
         '''
-            NOTE: Currently importHook will accept the keyword-argument "level"
-            but it will *NOT* use it (currently). Details about the "level" keyword
-            argument can be found here: http://www.python.org/doc/2.5.2/lib/built-in-funcs.html
+        NOTE: Currently importHook will accept the keyword-argument "level"
+        but it will *NOT* use it. Details about the "level" keyword
+        argument can be found here:
+        https://docs.python.org/2/library/functions.html#__import__
         '''
         # first see if we could be importing a relative name
         _sys_modules_get = sys.modules.get
@@ -435,14 +469,14 @@ class ImportManager:
             if i:
                 break
 
-        if i<len(nmparts):
+        if i < len(nmparts):
             if ctx and hasattr(sys.modules[ctx], nmparts[i]):
                 return sys.modules[nmparts[0]]
             del sys.modules[fqname]
             raise ImportError("No module named %s" % fqname)
         if fromlist is None:
             if context:
-                return sys.modules[context+'.'+nmparts[0]]
+                return sys.modules[context + '.' + nmparts[0]]
             return sys.modules[nmparts[0]]
         bottommod = sys.modules[ctx]
         if hasattr(bottommod, '__path__'):
@@ -451,7 +485,7 @@ class ImportManager:
             while i < len(fromlist):
                 nm = fromlist[i]
                 if nm == '*':
-                    fromlist[i:i+1] = list(getattr(bottommod, '__all__', []))
+                    fromlist[i:i+1] = list(getattr(bottommod, '__all__', []))  # noqa: E226,E501 missing whitespace around operator
                     if i >= len(fromlist):
                         break
                     nm = fromlist[i]
@@ -459,7 +493,7 @@ class ImportManager:
                 if not hasattr(bottommod, nm):
                     if self.threaded:
                         self._acquire()
-                    mod = self.doimport(nm, ctx, ctx+'.'+nm)
+                    mod = self.doimport(nm, ctx, ctx + '.' + nm)
                     if self.threaded:
                         self._release()
                     if not mod:
@@ -505,7 +539,7 @@ class ImportManager:
         parentnm = packageName(fqnm)
         newmod = self.doimport(nm, parentnm, fqnm)
         mod.__dict__.update(newmod.__dict__)
-##        return newmod
+#        return newmod
 
     def _acquire(self):
         if self.rlock.locked():
@@ -524,7 +558,7 @@ class ImportManager:
 
 
 ##################################################
-## MORE CONSTANTS & GLOBALS
+# MORE CONSTANTS & GLOBALS
 
 _globalOwnerTypes = [
     DirOwner,
